use 5.006;    # our
use strict;
use warnings;

package Gentoo::App::Demerge;

our $VERSION = '0.048';

=head1 NAME

Gentoo::App::Demerge - Revert to previous installation states.

=head1 AUTHOR

Christian Hartmann <ian@gentoo.org>

=head1 CONTRIBUTORS

Many thanks go out to all the people listed below:

Wernfried Haas <amne@gentoo.org>

Tobias Scherbaum <dertobi123@gentoo.org>

Kalin Kozhuharov <me.kalin@gmail.com>

Michael Cummings <mcummings@gentoo.org>

Raul Porcel <armin76@gentoo.org>

pille <pille@struction.de>

=head1 LICENSE

This software is copyright (C) 2007 by Christian Hartmann.

This is free software; you can redistribute it and/or modify it under
The GNU General Public License, Version 2, June 1991

=cut
